@@ -1,5 +1,24 @@
+/*
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include "AudioDialog.h"
-#define Inherited AudioDialogData
+#include "GlobalIcon.h"
+
+#include <qcombobox.h>
+#include <qradiobutton.h>
 
 static int frequencyList[] = 
 {
@@ -8,11 +27,11 @@ static int frequencyList[] =
     0  // end
 };
 
-AudioDialog::AudioDialog(QWidget* parent, const char* name) : Inherited(parent,name)
+AudioDialog::AudioDialog(QWidget* parent, const char* name) 
+: AudioDialogData(parent,name)
 {
-    setCaption("Audio Configuration");
     setFixedSize(width(),height());
-    setIcon(*myMainIcon);
+    setIcon(*mainIcon);
     
     setButtons();
 }
