@@ -1,14 +1,34 @@
+/*
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
+#include <qcheckbox.h>
+#include <qradiobutton.h>
+
 #include "EmuDialog.h"
-#define Inherited EmuDialogData
+#include "GlobalIcon.h"
 
-EmuDialog::EmuDialog(QWidget* parent, const char* name)	: Inherited(parent,name)
+EmuDialog::EmuDialog(QWidget* parent, const char* name)
+: EmuDialogData(parent,name,false,0)
 {
-    setCaption( "Emulation" );
     setFixedSize(width(),height());
-    setIcon(*myMainIcon);
+    setIcon(*mainIcon);
 
-    enableChangedSignal(true);
+    enableChangedSignal(false);
     setButtons();
+    enableChangedSignal(true);
 }
 
 void EmuDialog::enableChangedSignal(bool val)
@@ -57,7 +77,7 @@ void EmuDialog::setButtons()
     measVol->setChecked(config.measuredVolume);
     mos8580->setChecked(config.mos8580);
     forceSS->setChecked(config.forceSongSpeed);
-	
+    
     fullBS->setChecked(config.memoryMode==MPU_BANK_SWITCHING);
     transROM->setChecked(config.memoryMode==MPU_TRANSPARENT_ROM);
     psidEnv->setChecked(config.memoryMode==MPU_PLAYSID_ENVIRONMENT);
@@ -94,3 +114,4 @@ void EmuDialog::newCLKsetting(int)
         config.clockSpeed = SIDTUNE_CLOCK_NTSC;
     emitChangedIfEnabled();
 }
+
