@@ -1,19 +1,41 @@
+/*
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
+#include <stdlib.h>
+#include <sidplay/sidtune.h>
+
+#include <qevent.h>
+#include <qlabel.h>
+#include <qlineedit.h>
+#include <qlistbox.h>
+#include <qmessagebox.h>
+#include <qpushbutton.h>
+
+#include "GlobalIcon.h"
 #include "HistoryDialog.h"
 
-HistoryDialog::HistoryDialog(QWidget* parent, const char* name) : HistoryDialogData(parent,name)
+HistoryDialog::HistoryDialog(QWidget* parent, const char* name)
+: HistoryDialogData(parent,name), file(0)
 {
-    setCaption( "History" );
-    setIcon(*myMainIcon);
-    setMinimumSize(width(),142);
+    setIcon(*mainIcon);
+    setMinimumSize(width(),140);
  
-	nextButton->setFocus();
-
     list.setAutoDelete(true);
+    list.clear();
     maxItems = 200;
-    autoAdd = true;
-    
-    file = new HistoryFile(".sidplay-history");
-    file->load(*this);
     
     QString tmp;
     tmp.sprintf("%d",maxItems);
@@ -22,26 +44,40 @@ HistoryDialog::HistoryDialog(QWidget* parent, const char* name) : HistoryDialogD
 
 HistoryDialog::~HistoryDialog()
 {
-    delete file;
+    if ( file!= 0)
+        delete file;
+}
+
+bool HistoryDialog::load(const char* fileName)
+{
+    if ( file!=0 )
+        delete file;
+    file = new HistoryFile(fileName);
+    return file->load(*this);
+}
+
+bool HistoryDialog::save()
+{
+    if ( file!=0 )
+        return file->save(*this);
+    else
+        return false;
 }
 
 void HistoryDialog::add(const char* fileName, const char* info)
 {
-    if (autoAdd)
+    if (list.count() >= maxItems)
     {
-        if (list.count() >= maxItems)
-        {
-            list.removeFirst();
-            historyListBox->removeItem(0);
-        }
-        list.append(new HistoryItem(fileName,info));
-        historyListBox->insertItem(info);
+        list.removeFirst();
+        historyListBox->removeItem(0);
     }
+    list.append(new HistoryItem(fileName,info));
+    historyListBox->insertItem(info);
 }
 
 void HistoryDialog::historyItemHighlighted(int index)
 {
-    emit playHistoryEntry(list.at(index)->fileName());
+    emit playHistoryItem(list.at(index)->fileName());
 }
 
 void HistoryDialog::prevButtonClicked()
@@ -79,7 +115,7 @@ void HistoryDialog::deleteButtonClicked()
 
 void HistoryDialog::clearButtonClicked()
 {
-    if (!list.isEmpty())
+    if ( !list.isEmpty() )
     {
         QMessageBox mb( "SIDPLAY",
                        "Do you really want to clear the history?",
@@ -105,7 +141,7 @@ void HistoryDialog::clearButtonClicked()
 
 void HistoryDialog::historySizeChanged()
 {
-    maxItems = atoi(sizeLineEdit->text());
+    maxItems = sizeLineEdit->text().toInt();
     while (list.count() > maxItems)
     {
         list.removeFirst();
@@ -118,16 +154,11 @@ void HistoryDialog::resizeEvent(QResizeEvent*)
     int w = width();
     int h = height();
     
-    historyListBox->setGeometry(10,10,w-20,h-90);
-    deleteButton->move(160,h-70);
-    prevButton->move(150,h-40);
-    nextButton->move(40,h-40);
+    historyListBox->setGeometry(0,0,w-0,h-84);
+    deleteButton->move(150,h-70);
     clearButton->move(220,h-70);
-    sizeLineEdit->move(100,h-70);
-    maxEntriesLabel->move(20,h-70);
-}
-
-bool HistoryDialog::save()
-{
-    return file->save(*this);
+    prevButton->move(40,h-40);
+    nextButton->move(160,h-40);
+    maxItemsLabel->move(10,h-70);
+    sizeLineEdit->move(90,h-70);
 }
