@@ -1,3 +1,19 @@
+/*
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 // This file is a mess. Instead of normal Qt toggle-buttons more flexible
 // ones should have been used. 
 // The mixer depends on emuConfig-like info to allow correct setting of
@@ -5,56 +21,58 @@
 //
 // Notes: Have to set LEDs manually (toggle/setChecked).
 
-#include "MixerDialog.h"
+#include <qbuttongroup.h>
+#include <qpushbutton.h>
+#include <qslider.h>
 
-#define Inherited MixerDialogData
+#include "MixerDialog.h"
 
 // --------------------------------------------------------------------------
 
 const int MixerDialog::voices = _voices;
 const int MixerDialog::effects = _effects;
 
-MixerDialog::MixerDialog(QWidget* parent, const char* name) : Inherited(parent,name)
+MixerDialog::MixerDialog(QWidget* parent, const char* name)
+: MixerDialogData(parent,name)
 {
-	setCaption( "Software Mixer" );
-	setFixedSize(width(),height());
-	setIcon(*myMainIcon);
+    setFixedSize(width(),height());
+    setIcon(*mainIcon);
 
-	mixerOffBtn->setColour(LEDButton::red);
-	mixerOffBtn->setText( "Off" );
-	mixerOffBtn->setAutoRepeat( FALSE );
-	connect( mixerOffBtn, SIGNAL(clicked()), SLOT(setMixerOff()) );
-	mixerGrp->insert(mixerOffBtn);
+    mixerOffBtn->setColour(LEDButton::red);
+    mixerOffBtn->setText( "Off" );
+    mixerOffBtn->setAutoRepeat( FALSE );
+    connect( mixerOffBtn, SIGNAL(clicked()), SLOT(setMixerOff()) );
+    mixerGrp->insert(mixerOffBtn);
 
-	highQualityBtn->setColour(LEDButton::green);
-	highQualityBtn->setText( "High quality" );
-	highQualityBtn->setAutoRepeat( FALSE );
-	connect( highQualityBtn, SIGNAL(clicked()), SLOT(setHighQuality()) );
-	mixerGrp->insert(highQualityBtn);
-	
-	fullPanningBtn->setColour(LEDButton::green);
-	fullPanningBtn->setText( "Full panning" );
-	fullPanningBtn->setAutoRepeat( FALSE );
-	connect( fullPanningBtn, SIGNAL(clicked()), SLOT(setFullPanning()) );
-	mixerGrp->insert(fullPanningBtn);
-	
-	effectsOffBtn->setColour(LEDButton::red);
-	effectsOffBtn->setText( "None" );
-	effectsOffBtn->setAutoRepeat( FALSE );
-	connect( effectsOffBtn, SIGNAL(clicked()), SLOT(setEffectsOff()) );
-	effectsGrp->insert(effectsOffBtn);
-	
-	surroundBtn->setColour(LEDButton::green);
-	surroundBtn->setText( "Surround" );
-	surroundBtn->setAutoRepeat( FALSE );
-	connect( surroundBtn, SIGNAL(clicked()), SLOT(setStereoSurround()) );
-	effectsGrp->insert(surroundBtn);
-	
-	centeredPanningBtn->setColour(LEDButton::green);
-	centeredPanningBtn->setText( "Centered AP" );
-	centeredPanningBtn->setAutoRepeat( FALSE );
-	connect( centeredPanningBtn, SIGNAL(clicked()), SLOT(setCenteredPanning()) );
-	effectsGrp->insert(centeredPanningBtn);
+    highQualityBtn->setColour(LEDButton::green);
+    highQualityBtn->setText( "High quality" );
+    highQualityBtn->setAutoRepeat( FALSE );
+    connect( highQualityBtn, SIGNAL(clicked()), SLOT(setHighQuality()) );
+    mixerGrp->insert(highQualityBtn);
+    
+    fullPanningBtn->setColour(LEDButton::green);
+    fullPanningBtn->setText( "Full panning" );
+    fullPanningBtn->setAutoRepeat( FALSE );
+    connect( fullPanningBtn, SIGNAL(clicked()), SLOT(setFullPanning()) );
+    mixerGrp->insert(fullPanningBtn);
+    
+    effectsOffBtn->setColour(LEDButton::red);
+    effectsOffBtn->setText( "None" );
+    effectsOffBtn->setAutoRepeat( FALSE );
+    connect( effectsOffBtn, SIGNAL(clicked()), SLOT(setEffectsOff()) );
+    effectsGrp->insert(effectsOffBtn);
+    
+    surroundBtn->setColour(LEDButton::green);
+    surroundBtn->setText( "Surround" );
+    surroundBtn->setAutoRepeat( FALSE );
+    connect( surroundBtn, SIGNAL(clicked()), SLOT(setStereoSurround()) );
+    effectsGrp->insert(surroundBtn);
+    
+    centeredPanningBtn->setColour(LEDButton::green);
+    centeredPanningBtn->setText( "Centered AP" );
+    centeredPanningBtn->setAutoRepeat( FALSE );
+    connect( centeredPanningBtn, SIGNAL(clicked()), SLOT(setCenteredPanning()) );
+    effectsGrp->insert(centeredPanningBtn);
 
     // Default volume levels.
     config.volHQ[0].l = config.volHQ[1].r = config.volHQ[2].l = config.volHQ[3].r = 255;
@@ -64,47 +82,40 @@ MixerDialog::MixerDialog(QWidget* parent, const char* name) : Inherited(parent,n
     config.volTotal[0] = config.volTotal[1] = config.volTotal[2] = config.volTotal[3] = 256;  // max
     config.muteMask[0] = config.muteMask[1] = config.muteMask[2] = config.muteMask[3] = 65535; // on
 
-	volSliders[0] = voice1volSld;
-	volSliders[1] = voice2volSld;
-	volSliders[2] = voice3volSld;
-	volSliders[3] = voice4volSld;
+    volSliders[0] = voice1volSld;
+    volSliders[1] = voice2volSld;
+    volSliders[2] = voice3volSld;
+    volSliders[3] = voice4volSld;
 
-	panSliders[0] = voice1panSld;
-	panSliders[1] = voice2panSld;
-	panSliders[2] = voice3panSld;
-	panSliders[3] = voice4panSld;
+    panSliders[0] = voice1panSld;
+    panSliders[1] = voice2panSld;
+    panSliders[2] = voice3panSld;
+    panSliders[3] = voice4panSld;
 
-	muteButtons[0] = voice1muteBtn;
-	muteButtons[1] = voice2muteBtn;
-	muteButtons[2] = voice3muteBtn;
-	muteButtons[3] = voice4muteBtn;
+    muteButtons[0] = voice1muteBtn;
+    muteButtons[1] = voice2muteBtn;
+    muteButtons[2] = voice3muteBtn;
+    muteButtons[3] = voice4muteBtn;
 
-	soloButtons[0] = voice1soloBtn;
-	soloButtons[1] = voice2soloBtn;
-	soloButtons[2] = voice3soloBtn;
-	soloButtons[3] = voice4soloBtn;
+    soloButtons[0] = voice1soloBtn;
+    soloButtons[1] = voice2soloBtn;
+    soloButtons[2] = voice3soloBtn;
+    soloButtons[3] = voice4soloBtn;
 
-	effectWidgets[0] = effectsOffBtn;
-	effectWidgets[1] = surroundBtn;
-	effectWidgets[2] = centeredPanningBtn;
+    effectWidgets[0] = effectsOffBtn;
+    effectWidgets[1] = surroundBtn;
+    effectWidgets[2] = centeredPanningBtn;
 
     dontTouchMuteButtons = false;
     soloIsVoice = (-1);
 
     changedSignalEnabled = true;
 
-	setButtons();
+    setButtons();
 }
 
 MixerDialog::~MixerDialog()
-{/*
-    delete mixerOffBtn;
-    delete highQualityBtn;
-    delete fullPanningBtn;
-    delete effectsOffBtn;
-    delete surroundBtn;
-    delete centeredPanningBtn;
-  */
+{
 }
 
 // --------------------------------------------------------------------------
@@ -149,10 +160,10 @@ void MixerDialog::setButtons()
     }
     adjustPanningSliders();
     
-	// Preset LEDs, sliders, buttons.
-	
-	if (config.channels == SIDEMU_MONO)
-	{
+    // Preset LEDs, sliders, buttons.
+    
+    if (config.channels == SIDEMU_MONO)
+    {
         if (config.mixingMode == SIDEMU_NONE)
         {
             setMixerButtons(true,false,false);
@@ -167,8 +178,8 @@ void MixerDialog::setButtons()
         enableEffects(false);
         fullPanningBtn->setEnabled(false);
         enablePanning(false);
-	}
-	else if (config.channels == SIDEMU_STEREO)
+    }
+    else if (config.channels == SIDEMU_STEREO)
     {
         if (config.mixingMode == SIDEMU_NONE)
         {
@@ -306,8 +317,8 @@ void MixerDialog::adjustPanningSliders()
 
 void MixerDialog::setMixerOff()
 {
-	if ( !mixerOffBtn->isChecked() )
-	{
+    if ( !mixerOffBtn->isChecked() )
+    {
         enableChangedSignal(false);
         
         config.mixingMode = SIDEMU_NONE;
@@ -318,344 +329,344 @@ void MixerDialog::setMixerOff()
 
         enableChangedSignal(true);
         emitChangedIfEnabled();
-	}
+    }
 }
 
 void MixerDialog::setHighQuality()
 {
-	if ( !highQualityBtn->isChecked() )
-	{
+    if ( !highQualityBtn->isChecked() )
+    {
         enableChangedSignal(false);
         
-		config.mixingMode = SIDEMU_VOLCONTROL;
-		config.panningMode = SIDEMU_NONE;
-		unMuteAllVoices();
-		setButtons();
+        config.mixingMode = SIDEMU_VOLCONTROL;
+        config.panningMode = SIDEMU_NONE;
+        unMuteAllVoices();
+        setButtons();
         
         enableChangedSignal(true);
         emitChangedIfEnabled();
-	}
+    }
 }
 
 void MixerDialog::setFullPanning()
 {
-	if ( !fullPanningBtn->isChecked() )
-	{
+    if ( !fullPanningBtn->isChecked() )
+    {
         enableChangedSignal(false);
         
-		config.mixingMode = SIDEMU_FULLPANNING;
-		config.panningMode = SIDEMU_NONE;
-		unMuteAllVoices();
-		setButtons();
+        config.mixingMode = SIDEMU_FULLPANNING;
+        config.panningMode = SIDEMU_NONE;
+        unMuteAllVoices();
+        setButtons();
         
         enableChangedSignal(true);
         emitChangedIfEnabled();
-	}
+    }
 }
 
 void MixerDialog::setEffectsOff()
 {
-	if ( !effectsOffBtn->isChecked() )
-	{
+    if ( !effectsOffBtn->isChecked() )
+    {
         enableChangedSignal(false);
         
-		config.mixingMode = SIDEMU_FULLPANNING;
-		config.panningMode = SIDEMU_NONE;
-		unMuteAllVoices();
+        config.mixingMode = SIDEMU_FULLPANNING;
+        config.panningMode = SIDEMU_NONE;
+        unMuteAllVoices();
         setButtons();
         
         enableChangedSignal(true);
         emitChangedIfEnabled();
-	}
+    }
 }
 
 void MixerDialog::setStereoSurround()
 {
-	if ( !surroundBtn->isChecked() )
-	{
+    if ( !surroundBtn->isChecked() )
+    {
         enableChangedSignal(false);
         
-		config.mixingMode = SIDEMU_STEREOSURROUND;
-		config.panningMode = SIDEMU_NONE;
-		unMuteAllVoices();
+        config.mixingMode = SIDEMU_STEREOSURROUND;
+        config.panningMode = SIDEMU_NONE;
+        unMuteAllVoices();
         setButtons();
         
         enableChangedSignal(true);
         emitChangedIfEnabled();
-	}
+    }
 }
 
 void MixerDialog::setCenteredPanning()
 {
-	if ( !centeredPanningBtn->isChecked() )
-	{
+    if ( !centeredPanningBtn->isChecked() )
+    {
         enableChangedSignal(false);
         
-		config.mixingMode = SIDEMU_FULLPANNING;
-		config.panningMode = SIDEMU_CENTEREDAUTOPANNING;
-		unMuteAllVoices();
+        config.mixingMode = SIDEMU_FULLPANNING;
+        config.panningMode = SIDEMU_CENTEREDAUTOPANNING;
+        unMuteAllVoices();
         setButtons();
         
         enableChangedSignal(true);
         emitChangedIfEnabled();
-	}
+    }
 }
 
 // -------------------------------------------------------------------- Slots
 
 void MixerDialog::setVoice1Volume(int val)
 {
-	newVoiceGain(1,val);
+    newVoiceGain(1,val);
     emitChangedIfEnabled();
 }
 
 void MixerDialog::setVoice2Volume(int val)
 {
-	newVoiceGain(2,val);
+    newVoiceGain(2,val);
     emitChangedIfEnabled();
 }
 
 void MixerDialog::setVoice3Volume(int val)
 {
-	newVoiceGain(3,val);
+    newVoiceGain(3,val);
     emitChangedIfEnabled();
 }
 
 void MixerDialog::setVoice4Volume(int val)
 {
-	newVoiceGain(4,val);
+    newVoiceGain(4,val);
     emitChangedIfEnabled();
 }
 
 void MixerDialog::setVoice1Pan(int val)
 {
-	newVoicePanPos(1,val);
-	if ((config.channels==SIDEMU_STEREO)
-		&&(config.mixingMode==SIDEMU_VOLCONTROL))
-	{
-		voice2panSld->setValue(255-val);
-		newVoicePanPos(2,val);
-	}
+    newVoicePanPos(1,val);
+    if ((config.channels==SIDEMU_STEREO)
+        &&(config.mixingMode==SIDEMU_VOLCONTROL))
+    {
+        voice2panSld->setValue(255-val);
+        newVoicePanPos(2,val);
+    }
     emitChangedIfEnabled();
 }
 
 void MixerDialog::setVoice2Pan(int val)
 {
-	newVoicePanPos(2,val);
-	if ((config.channels==SIDEMU_STEREO)
-		&&(config.mixingMode==SIDEMU_VOLCONTROL))
-	{
-		voice1panSld->setValue(255-val);
-		newVoicePanPos(1,val);
-	}
+    newVoicePanPos(2,val);
+    if ((config.channels==SIDEMU_STEREO)
+        &&(config.mixingMode==SIDEMU_VOLCONTROL))
+    {
+        voice1panSld->setValue(255-val);
+        newVoicePanPos(1,val);
+    }
     emitChangedIfEnabled();
 }
 
 void MixerDialog::setVoice3Pan(int val)
 {
-	newVoicePanPos(3,val);
-	if ((config.channels==SIDEMU_STEREO)
-		&&(config.mixingMode==SIDEMU_VOLCONTROL))
-	{
-		voice4panSld->setValue(255-val);
-		newVoicePanPos(4,val);
-	}
+    newVoicePanPos(3,val);
+    if ((config.channels==SIDEMU_STEREO)
+        &&(config.mixingMode==SIDEMU_VOLCONTROL))
+    {
+        voice4panSld->setValue(255-val);
+        newVoicePanPos(4,val);
+    }
     emitChangedIfEnabled();
 }
 
 void MixerDialog::setVoice4Pan(int val)
 {
-	newVoicePanPos(4,val);
-	if ((config.channels==SIDEMU_STEREO)
-		&&(config.mixingMode==SIDEMU_VOLCONTROL))
-	{
-		voice3panSld->setValue(255-val);
-		newVoicePanPos(3,val);
-	}
+    newVoicePanPos(4,val);
+    if ((config.channels==SIDEMU_STEREO)
+        &&(config.mixingMode==SIDEMU_VOLCONTROL))
+    {
+        voice3panSld->setValue(255-val);
+        newVoicePanPos(3,val);
+    }
     emitChangedIfEnabled();
 }
 
 void MixerDialog::soloVoice1(bool val)
 {
-	if (val)
-	{
-		currentSoloButtonOff();
-		muteVoice(1,false);
-		muteVoice(2,true);
-		muteVoice(3,true);
-		muteVoice(4,true);
-		adjustMuteButtons();
-		soloIsVoice = 1;
-	}
-	else
-	{
-		soloIsVoice = (-1);
-		if (!dontTouchMuteButtons)
-		{
-			unMuteAllVoices();
-			muteVoice(2,false);
-			muteVoice(3,false);
-			muteVoice(4,false);
-			adjustMuteButtons();
-		}
-	}
+    if (val)
+    {
+        currentSoloButtonOff();
+        muteVoice(1,false);
+        muteVoice(2,true);
+        muteVoice(3,true);
+        muteVoice(4,true);
+        adjustMuteButtons();
+        soloIsVoice = 1;
+    }
+    else
+    {
+        soloIsVoice = (-1);
+        if (!dontTouchMuteButtons)
+        {
+            unMuteAllVoices();
+            muteVoice(2,false);
+            muteVoice(3,false);
+            muteVoice(4,false);
+            adjustMuteButtons();
+        }
+    }
     emitChangedIfEnabled();
 }
 
 void MixerDialog::soloVoice2(bool val)
 {
-	if (val)
-	{
-		currentSoloButtonOff();
-		muteVoice(2,false);
-		muteVoice(1,true);
-		muteVoice(3,true);
-		muteVoice(4,true);
-		adjustMuteButtons();
-		soloIsVoice = 2;
-	}
-	else
-	{
-		soloIsVoice = (-1);
-		if (!dontTouchMuteButtons)
-		{
-			unMuteAllVoices();
-			muteVoice(1,false);
-			muteVoice(3,false);
-			muteVoice(4,false);
-			adjustMuteButtons();
-		}
-	}
+    if (val)
+    {
+        currentSoloButtonOff();
+        muteVoice(2,false);
+        muteVoice(1,true);
+        muteVoice(3,true);
+        muteVoice(4,true);
+        adjustMuteButtons();
+        soloIsVoice = 2;
+    }
+    else
+    {
+        soloIsVoice = (-1);
+        if (!dontTouchMuteButtons)
+        {
+            unMuteAllVoices();
+            muteVoice(1,false);
+            muteVoice(3,false);
+            muteVoice(4,false);
+            adjustMuteButtons();
+        }
+    }
     emitChangedIfEnabled();
 }
 
 void MixerDialog::soloVoice3(bool val)
 {
-	if (val)
-	{
-		currentSoloButtonOff();
-		muteVoice(3,false);
-		muteVoice(1,true);
-		muteVoice(2,true);
-		muteVoice(4,true);
-		adjustMuteButtons();
-		soloIsVoice = 3;
-	}
-	else
-	{
-		soloIsVoice = (-1);
-		if (!dontTouchMuteButtons)
-		{
-			unMuteAllVoices();
-			muteVoice(1,false);
-			muteVoice(2,false);
-			muteVoice(4,false);
-			adjustMuteButtons();
-		}
-	}
+    if (val)
+    {
+        currentSoloButtonOff();
+        muteVoice(3,false);
+        muteVoice(1,true);
+        muteVoice(2,true);
+        muteVoice(4,true);
+        adjustMuteButtons();
+        soloIsVoice = 3;
+    }
+    else
+    {
+        soloIsVoice = (-1);
+        if (!dontTouchMuteButtons)
+        {
+            unMuteAllVoices();
+            muteVoice(1,false);
+            muteVoice(2,false);
+            muteVoice(4,false);
+            adjustMuteButtons();
+        }
+    }
     emitChangedIfEnabled();
 }
 
 void MixerDialog::soloVoice4(bool val)
 {
-	if (val)
-	{
-		currentSoloButtonOff();
-		muteVoice(4,false);
-		muteVoice(1,true);
-		muteVoice(2,true);
-		muteVoice(3,true);
-		adjustMuteButtons();
-		soloIsVoice = 4;
-	}
-	else
-	{
-		soloIsVoice = (-1);
-		if (!dontTouchMuteButtons)
-		{
-			unMuteAllVoices();
-			muteVoice(1,false);
-			muteVoice(2,false);
-			muteVoice(3,false);
-			adjustMuteButtons();
-		}
-	}
+    if (val)
+    {
+        currentSoloButtonOff();
+        muteVoice(4,false);
+        muteVoice(1,true);
+        muteVoice(2,true);
+        muteVoice(3,true);
+        adjustMuteButtons();
+        soloIsVoice = 4;
+    }
+    else
+    {
+        soloIsVoice = (-1);
+        if (!dontTouchMuteButtons)
+        {
+            unMuteAllVoices();
+            muteVoice(1,false);
+            muteVoice(2,false);
+            muteVoice(3,false);
+            adjustMuteButtons();
+        }
+    }
     emitChangedIfEnabled();
 }
 
 void MixerDialog::muteVoice1(bool val)
 {
-	dontTouchMuteButtons = true;
-	if (val)
-	{
-		currentSoloButtonOff();
-		muteVoice(1,true);
-		adjustMuteButtons();
-	}
-	else
-	{
-		currentSoloButtonOff();
-		muteVoice(1,false);
-		adjustMuteButtons();
-	}
-	dontTouchMuteButtons = false;
+    dontTouchMuteButtons = true;
+    if (val)
+    {
+        currentSoloButtonOff();
+        muteVoice(1,true);
+        adjustMuteButtons();
+    }
+    else
+    {
+        currentSoloButtonOff();
+        muteVoice(1,false);
+        adjustMuteButtons();
+    }
+    dontTouchMuteButtons = false;
     emitChangedIfEnabled();
 }
 
 void MixerDialog::muteVoice2(bool val)
 {
-	dontTouchMuteButtons = true;
-	if (val)
-	{
-		currentSoloButtonOff();
-		muteVoice(2,true);
-		adjustMuteButtons();
-	}
-	else
-	{
-		currentSoloButtonOff();
-		muteVoice(2,false);
-		adjustMuteButtons();
-	}
-	dontTouchMuteButtons = false;
+    dontTouchMuteButtons = true;
+    if (val)
+    {
+        currentSoloButtonOff();
+        muteVoice(2,true);
+        adjustMuteButtons();
+    }
+    else
+    {
+        currentSoloButtonOff();
+        muteVoice(2,false);
+        adjustMuteButtons();
+    }
+    dontTouchMuteButtons = false;
     emitChangedIfEnabled();
 }
 
 void MixerDialog::muteVoice3(bool val)
 {
-	dontTouchMuteButtons = true;
-	if (val)
-	{
-		currentSoloButtonOff();
-		muteVoice(3,true);
-		adjustMuteButtons();
-	}
-	else
-	{
-		currentSoloButtonOff();
-		muteVoice(3,false);
-		adjustMuteButtons();
-	}
-	dontTouchMuteButtons = false;
+    dontTouchMuteButtons = true;
+    if (val)
+    {
+        currentSoloButtonOff();
+        muteVoice(3,true);
+        adjustMuteButtons();
+    }
+    else
+    {
+        currentSoloButtonOff();
+        muteVoice(3,false);
+        adjustMuteButtons();
+    }
+    dontTouchMuteButtons = false;
     emitChangedIfEnabled();
 }
 
 void MixerDialog::muteVoice4(bool val)
 {
-	dontTouchMuteButtons = true;
-	if (val)
-	{
-		currentSoloButtonOff();
-		muteVoice(4,true);
-		adjustMuteButtons();
-	}
-	else
-	{
-		currentSoloButtonOff();
-		muteVoice(4,false);
-		adjustMuteButtons();
-	}
-	dontTouchMuteButtons = false;
+    dontTouchMuteButtons = true;
+    if (val)
+    {
+        currentSoloButtonOff();
+        muteVoice(4,true);
+        adjustMuteButtons();
+    }
+    else
+    {
+        currentSoloButtonOff();
+        muteVoice(4,false);
+        adjustMuteButtons();
+    }
+    dontTouchMuteButtons = false;
     emitChangedIfEnabled();
 }
 
@@ -698,7 +709,7 @@ void MixerDialog::newVoicePanPos(int voice, int val)
         if (config.channels == SIDEMU_STEREO)
         {
             if (config.mixingMode == SIDEMU_VOLCONTROL)
-			{
+            {
                 config.volHQ[vi].l = left;
                 config.volHQ[vi].r = right;
             }
