@@ -1,16 +1,21 @@
 // Not finished. And should check sample encoding as well.
 
+#include <math.h>
+
+#include <qpainter.h>
+#include <qpixmap.h>
+
 #include "WaveViewDialog.h"
+#include "GlobalIcon.h"
 #include "images/waveview.xpm"
 
-#define Inherited WaveViewDialogData
-
-WaveViewDialog::WaveViewDialog(QWidget* parent,	const char* name) : Inherited(parent,name)
+WaveViewDialog::WaveViewDialog(QWidget* parent, const char* name)
+: WaveViewDialogData(parent,name,false,0)
 {
     setCaption( "Oscilloscope" );
     setFixedSize(width(),height());
-    setIcon(*myMainIcon);
-	
+    setIcon(*mainIcon);
+    
     myWavePicOrig = new QPixmap(waveview_xpm);
     lastBuffer = 0;
     shown = false;
@@ -49,14 +54,14 @@ void WaveViewDialog::paintWaveformFunc(const void* buffer)
         return;
 
     lastBuffer = buffer;
-	
+    
     QColor myBeam1Color(0,255,0);  // rgb
     QColor myBeam2Color(0,255,192);  // rgb
-	
+    
     QPixmap myWavePic(width(),height());
     QColor myBgColor(0,0,0);  // rgb
     myWavePic.fill(myBgColor);
-	
+    
     QPainter paintBuf;
     paintBuf.begin(&myWavePic);
     paintBuf.drawPixmap(0,0,*myWavePicOrig);
@@ -89,8 +94,8 @@ void WaveViewDialog::paintWaveformFunc(const void* buffer)
                 i += di;
             }
         }
-		else  // MONO
-		{
+        else  // MONO
+        {
             paintBuf.setPen(myBeam1Color);
             di = 1;
             // current point
@@ -143,9 +148,9 @@ void WaveViewDialog::paintWaveformFunc(const void* buffer)
             }
         }
     }
-	
+    
     paintBuf.end();
-		
+    
     QPainter paint(this);
     paint.drawPixmap(0,0,myWavePic);
 }
